
# q-expansion of newform 2744.2.a.h, downloaded from the LMFDB on 03 July 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 2744
weight = 2
poly_data = [8, 0, -1164, 0, 2574, 0, -1393, 0, 304, 0, -29, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[1782, 0, -226709, 0, 97733, 0, -13379, 0, 680, 0, -9, 0], 18452], [[-94042, 0, 245161, 0, -97733, 0, 13379, 0, -680, 0, 9, 0], 18452], [[35004, 0, -310296, 0, 196769, 0, -36038, 0, 2283, 0, -37, 0], 73808], [[0, 35004, 0, -310296, 0, 196769, 0, -36038, 0, 2283, 0, -37], 73808], [[-33618, 0, 52983, 0, -24394, 0, 6155, 0, -729, 0, 30, 0], 18452], [[-174724, 0, 1543416, 0, -1198903, 0, 325418, 0, -36205, 0, 1395, 0], 73808], [[0, 1866780, 0, -5110644, 0, 2962367, 0, -670806, 0, 65553, 0, -2299], 73808], [[0, -1927444, 0, 5322576, 0, -3059943, 0, 695426, 0, -68469, 0, 2419], 73808], [[0, -3428164, 0, 7845348, 0, -4234717, 0, 919498, 0, -87419, 0, 3009], 73808], [[0, -2087480, 0, 4326658, 0, -2313319, 0, 502388, 0, -47767, 0, 1643], 36904]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [2, 0, 0, 1, 0, 0, -1, -1, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, -2, 0, -1, 0], [0, 1, 0, 0, 0, -1, 0, 0, 2, 1, 1, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0, 1, -1, -1], [1, 0, 0, 0, 2, 0, 1, 1, 0, 0, 0, 0], [0, 0, -1, 1, -1, 0, 1, 0, 0, 0, 0, 0], [0, -4, 0, 0, 0, 2, 0, 0, 1, 1, -3, 1], [-2, 0, -2, -1, 2, 0, -1, -1, 0, 0, 0, 0], [0, 1, 0, 0, 0, 1, 0, 0, 2, -1, 1, 0], [-1, 0, -1, -1, 1, 0, -3, 1, 0, 0, 0, 0], [0, -2, 0, 0, 0, 0, 0, 0, 1, 1, -1, 1], [-5, 0, -1, -1, 1, 0, -3, 1, 0, 0, 0, 0], [0, 3, 0, 0, 0, 2, 0, 0, -1, -2, 1, -3], [0, 1, 0, 0, 0, 0, 0, 0, -2, -1, 0, -2], [2, 0, -1, -1, 3, 0, -1, 0, 0, 0, 0, 0], [9, 0, -1, 0, -6, 0, 4, -2, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 1, 3, 1, 0], [6, 0, 0, -2, -3, 0, 5, 1, 0, 0, 0, 0], [0, 0, 0, 0, 0, -3, 0, 0, 0, 1, 0, 1], [0, -1, 0, 0, 0, -4, 0, 0, 3, 5, 1, 2], [0, 3, 0, 0, 0, 1, 0, 0, -2, -1, 3, 0], [0, -1, 0, 0, 0, -1, 0, 0, 1, 0, -3, 1], [0, -1, 0, 0, 0, 1, 0, 0, 1, 2, 2, 1], [6, 0, -1, 1, 3, 0, -5, 0, 0, 0, 0, 0], [-1, 0, -1, 1, 7, 0, -5, 1, 0, 0, 0, 0], [8, 0, 0, 2, -7, 0, 4, 0, 0, 0, 0, 0], [5, 0, -1, -2, -2, 0, -1, 1, 0, 0, 0, 0], [0, -5, 0, 0, 0, 2, 0, 0, -1, 1, -1, 3], [0, 0, 1, 2, -4, 0, -4, -3, 0, 0, 0, 0], [0, 3, 0, 0, 0, 1, 0, 0, -2, -5, 2, -4], [2, 0, 2, 3, 0, 0, 1, -3, 0, 0, 0, 0], [5, 0, -1, 0, -3, 0, 3, -2, 0, 0, 0, 0], [0, 4, 0, 0, 0, 0, 0, 0, -5, -5, 1, -2], [7, 0, 3, 3, -7, 0, 5, 1, 0, 0, 0, 0], [0, -5, 0, 0, 0, -1, 0, 0, 3, 6, -4, 7], [0, 0, 0, 0, 0, -1, 0, 0, 2, 1, -1, -3], [5, 0, -1, -3, 3, 0, -1, 1, 0, 0, 0, 0], [0, -9, 0, 0, 0, -1, 0, 0, 2, 3, -1, 5], [1, 0, -1, 2, 3, 0, -3, -2, 0, 0, 0, 0], [-3, 0, 0, -2, 12, 0, -7, 3, 0, 0, 0, 0], [-8, 0, -1, -1, 1, 0, 1, -2, 0, 0, 0, 0], [0, 3, 0, 0, 0, -6, 0, 0, -4, 0, 2, 1], [8, 0, 1, 1, 1, 0, -3, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, -2, 0, 0, 2, 0, 0, -3], [0, 2, 0, 0, 0, 2, 0, 0, 0, 0, 2, -5], [0, -2, 0, 0, 0, 1, 0, 0, -2, -5, -3, -2], [-11, 0, 1, -4, 4, 0, -2, 2, 0, 0, 0, 0], [-2, 0, 3, 4, -4, 0, -6, -1, 0, 0, 0, 0], [0, -1, 0, 0, 0, -4, 0, 0, 4, 0, 4, 1], [0, 7, 0, 0, 0, -5, 0, 0, -2, -3, 3, -2], [0, -12, 0, 0, 0, 7, 0, 0, -2, 1, -9, 5], [3, 0, 1, 2, -6, 0, 5, 1, 0, 0, 0, 0], [0, -2, 0, 0, 0, 6, 0, 0, 1, -1, -5, 2], [0, -4, 0, 0, 0, -1, 0, 0, 3, 0, -2, 0], [4, 0, 0, 1, -6, 0, 3, -1, 0, 0, 0, 0], [1, 0, -1, 0, -11, 0, 5, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 5, 0, 0, -1, -2, -1, 6], [0, -1, 0, 0, 0, 2, 0, 0, -5, -2, -5, 5], [0, -3, 0, 0, 0, 2, 0, 0, -4, 2, -4, 4], [0, 0, 0, 0, 0, -1, 0, 0, 1, -2, 4, -4], [0, -4, 0, 0, 0, 2, 0, 0, 1, 5, -1, -1], [-20, 0, 0, -1, 2, 0, 1, 1, 0, 0, 0, 0], [12, 0, 1, -1, -11, 0, -7, 0, 0, 0, 0, 0], [-3, 0, -3, 0, 8, 0, -13, -3, 0, 0, 0, 0], [0, 0, 2, 2, -8, 0, -2, 4, 0, 0, 0, 0], [0, -4, 0, 0, 0, -3, 0, 0, 1, 2, -4, 5], [0, -7, 0, 0, 0, 3, 0, 0, -1, 2, -4, -1], [-3, 0, -1, -1, -4, 0, -6, -4, 0, 0, 0, 0], [0, 0, 0, 0, 0, -3, 0, 0, 4, 3, 3, 1], [12, 0, 1, 3, -15, 0, 1, -2, 0, 0, 0, 0], [0, 0, 0, 2, 2, 0, -8, -6, 0, 0, 0, 0], [0, -5, 0, 0, 0, 4, 0, 0, 2, 4, -4, 3], [3, 0, 1, 5, -5, 0, 7, -5, 0, 0, 0, 0], [0, 0, 0, 0, 0, 3, 0, 0, 3, 2, 4, -4], [2, 0, -4, -2, -2, 0, 3, -2, 0, 0, 0, 0], [0, -2, 0, 0, 0, 2, 0, 0, 5, 5, 1, 1], [0, 3, 0, 0, 0, -1, 0, 0, -1, 1, 0, 6], [-5, 0, 3, 1, 7, 0, 7, 3, 0, 0, 0, 0], [9, 0, -1, 4, -12, 0, 10, -4, 0, 0, 0, 0], [0, -9, 0, 0, 0, 2, 0, 0, 2, 4, 4, 3], [0, 0, 0, 0, 0, 4, 0, 0, 4, -2, 0, 4], [6, 0, 2, 4, 0, 0, 4, 4, 0, 0, 0, 0], [0, 0, 6, 0, -5, 0, 1, 3, 0, 0, 0, 0], [1, 0, 2, -4, -3, 0, -3, 0, 0, 0, 0, 0], [0, -2, 0, 0, 0, 6, 0, 0, -6, -7, -2, 1], [1, 0, 1, 4, 0, 0, -7, 3, 0, 0, 0, 0], [0, 5, 0, 0, 0, -10, 0, 0, 7, 9, 7, -3], [0, 4, 0, 0, 0, 6, 0, 0, -8, -6, -2, 0], [7, 0, -1, 1, 3, 0, -6, -1, 0, 0, 0, 0], [-11, 0, -1, -3, 11, 0, -1, 1, 0, 0, 0, 0], [2, 0, -2, -3, -6, 0, -13, 1, 0, 0, 0, 0], [0, 0, 0, 0, 0, -6, 0, 0, 13, 5, 9, 3], [0, 8, 0, 0, 0, 3, 0, 0, -1, -2, 8, 1], [0, 2, 0, 0, 0, 1, 0, 0, 5, -2, 10, 2], [0, -10, 0, 0, 0, 0, 0, 0, 2, 9, -4, 5], [12, 0, 1, -1, -7, 0, -3, 0, 0, 0, 0, 0], [2, 0, 0, 1, 8, 0, -7, -5, 0, 0, 0, 0], [-9, 0, -1, -1, -15, 0, 1, 3, 0, 0, 0, 0], [0, 2, 0, 0, 0, 2, 0, 0, -5, -4, 1, -6], [18, 0, 1, -4, -10, 0, 12, -1, 0, 0, 0, 0], [25, 0, 1, 1, -5, 0, 9, 1, 0, 0, 0, 0], [0, -4, 0, 0, 0, -3, 0, 0, 3, 0, 4, 2], [0, 11, 0, 0, 0, -8, 0, 0, 6, 0, 7, -11], [0, -6, 0, 0, 0, -5, 0, 0, 8, 1, -3, 1], [-7, 0, -5, 3, 9, 0, -10, -3, 0, 0, 0, 0], [0, 4, 0, 0, 0, -2, 0, 0, -6, 0, 2, -2], [0, 2, 0, 0, 0, -3, 0, 0, -2, 7, -7, 7], [0, 0, 2, 7, 8, 0, 3, -1, 0, 0, 0, 0], [-12, 0, -2, -2, -9, 0, 3, 3, 0, 0, 0, 0], [0, -12, 0, 0, 0, 4, 0, 0, -3, 5, -14, 1], [-12, 0, 5, -1, 3, 0, -5, 0, 0, 0, 0, 0], [3, 0, -2, 0, -5, 0, 3, 4, 0, 0, 0, 0], [0, -1, 0, 0, 0, -2, 0, 0, -9, -1, -2, -2], [0, 1, 0, 0, 0, 4, 0, 0, 2, 0, -6, 9], [-30, 0, 0, 1, 2, 0, -3, 1, 0, 0, 0, 0], [-10, 0, -1, -1, 1, 0, 7, 10, 0, 0, 0, 0], [0, -3, 0, 0, 0, -6, 0, 0, -2, 5, -2, -4], [-13, 0, -1, 0, -4, 0, -14, 6, 0, 0, 0, 0], [0, -3, 0, 0, 0, -1, 0, 0, -3, 0, 3, -5], [0, 0, -2, -5, -2, 0, -7, -1, 0, 0, 0, 0], [0, -8, 0, 0, 0, 4, 0, 0, -1, -2, -3, -2], [2, 0, 0, 1, 6, 0, 3, -1, 0, 0, 0, 0], [-13, 0, 1, -1, 9, 0, -9, 11, 0, 0, 0, 0], [0, -4, 0, 0, 0, 2, 0, 0, 11, 1, 5, -5], [0, 2, 0, 0, 0, -7, 0, 0, 3, 2, -2, 6], [0, -8, 0, 0, 0, 6, 0, 0, -7, 1, -12, 5], [-10, 0, 1, 7, 3, 0, -9, 2, 0, 0, 0, 0], [4, 0, 2, -1, 11, 0, -11, -5, 0, 0, 0, 0], [-8, 0, 0, 0, -15, 0, 12, 0, 0, 0, 0, 0], [6, 0, -1, -1, 21, 0, -5, -4, 0, 0, 0, 0], [0, 1, 0, 0, 0, 9, 0, 0, -6, -15, -3, -2], [0, 2, 0, 0, 0, 1, 0, 0, 1, -4, -4, 4], [0, -3, 0, 0, 0, -7, 0, 0, 9, 7, 2, 2], [0, -1, 0, 0, 0, 5, 0, 0, -4, -3, -2, 2], [0, -1, 0, 0, 0, -1, 0, 0, 0, 9, -3, 3], [5, 0, 3, 0, 7, 0, -3, -6, 0, 0, 0, 0], [0, -14, 0, 0, 0, 5, 0, 0, 1, 2, 1, 6], [-15, 0, 1, -3, -1, 0, -25, -3, 0, 0, 0, 0], [-8, 0, 2, 2, 8, 0, -15, 4, 0, 0, 0, 0], [4, 0, 2, -4, -4, 0, 14, -2, 0, 0, 0, 0], [0, 5, 0, 0, 0, -1, 0, 0, 10, -3, 2, -6], [0, 3, 0, 0, 0, -6, 0, 0, 4, 0, 12, -1], [0, 5, 0, 0, 0, -1, 0, 0, -4, -3, 4, -4], [0, 4, 0, 0, 0, 0, 0, 0, 3, -11, 3, -5], [0, 1, 0, 0, 0, 4, 0, 0, 0, -3, 6, 4], [-20, 0, 4, 2, 18, 0, -9, 10, 0, 0, 0, 0], [2, 0, 1, -1, -19, 0, 1, 0, 0, 0, 0, 0], [0, -17, 0, 0, 0, 11, 0, 0, 5, 0, -4, 1], [-4, 0, 2, 1, 0, 0, -19, -1, 0, 0, 0, 0], [0, 9, 0, 0, 0, 0, 0, 0, 7, -5, 5, 4], [2, 0, -2, 1, 2, 0, 5, -1, 0, 0, 0, 0], [32, 0, 2, 5, -16, 0, 35, -3, 0, 0, 0, 0], [15, 0, -5, 1, 5, 0, 8, 1, 0, 0, 0, 0], [0, 10, 0, 0, 0, 0, 0, 0, 0, -8, 0, -8], [0, 9, 0, 0, 0, 1, 0, 0, 9, 4, 6, 5], [0, -15, 0, 0, 0, 1, 0, 0, -9, 6, -4, 1], [-13, 0, -1, -1, 17, 0, -19, -1, 0, 0, 0, 0], [15, 0, -3, -2, -8, 0, 9, -1, 0, 0, 0, 0], [9, 0, 4, 4, -11, 0, 13, 0, 0, 0, 0, 0], [0, -20, 0, 0, 0, 5, 0, 0, -4, 3, -7, 6], [3, 0, 3, -4, 8, 0, 5, -3, 0, 0, 0, 0], [0, 11, 0, 0, 0, -13, 0, 0, 10, 5, 17, -2], [-12, 0, 1, -1, 15, 0, 3, 0, 0, 0, 0, 0], [0, 6, 0, 0, 0, 4, 0, 0, -13, -13, -5, -7], [10, 0, 1, -2, -12, 0, 14, 5, 0, 0, 0, 0], [0, 0, 0, 0, 0, -9, 0, 0, -5, 3, 4, 1], [20, 0, -2, -4, -32, 0, 12, 0, 0, 0, 0, 0], [0, -6, 0, 0, 0, 7, 0, 0, -4, 3, -11, 5], [-3, 0, 0, -2, 12, 0, -17, 1, 0, 0, 0, 0], [2, 0, -6, -4, 11, 0, 13, 1, 0, 0, 0, 0], [0, -10, 0, 0, 0, 5, 0, 0, -3, 10, -4, 6], [0, 15, 0, 0, 0, -9, 0, 0, -3, 0, 6, 1], [28, 0, -3, 3, -11, 0, 1, -6, 0, 0, 0, 0], [-12, 0, -3, 7, 3, 0, -13, 0, 0, 0, 0, 0], [0, 7, 0, 0, 0, 1, 0, 0, -7, 6, 4, 3], [0, -7, 0, 0, 0, 0, 0, 0, 4, 10, -11, 7], [-7, 0, -1, -2, 2, 0, -8, -6, 0, 0, 0, 0], [0, 5, 0, 0, 0, -2, 0, 0, 4, 2, 10, 2], [-3, 0, -3, -5, 3, 0, -19, 3, 0, 0, 0, 0], [0, 6, 0, 0, 0, 0, 0, 0, 6, 4, -2, 8], [-27, 0, -6, -4, 21, 0, -17, -8, 0, 0, 0, 0], [0, 10, 0, 0, 0, -11, 0, 0, 6, 9, 8, -5], [17, 0, 3, 7, 5, 0, 19, 3, 0, 0, 0, 0], [0, -11, 0, 0, 0, 5, 0, 0, 1, 2, 0, 8], [31, 0, 3, -2, -11, 0, 21, 0, 0, 0, 0, 0], [0, -14, 0, 0, 0, -3, 0, 0, -3, 10, -16, -4], [0, 9, 0, 0, 0, 0, 0, 0, -14, -10, 6, 1], [11, 0, 5, 5, 3, 0, 13, -3, 0, 0, 0, 0], [-25, 0, 1, 3, 11, 0, -13, -5, 0, 0, 0, 0], [0, 15, 0, 0, 0, 2, 0, 0, -4, -12, 10, 0], [0, 0, 4, -1, 16, 0, -11, 3, 0, 0, 0, 0], [0, 8, 0, 0, 0, 0, 0, 0, -2, 0, 4, 0], [26, 0, -1, 0, -2, 0, -8, -3, 0, 0, 0, 0], [6, 0, -3, -3, -21, 0, 9, -2, 0, 0, 0, 0], [0, -9, 0, 0, 0, -4, 0, 0, 1, 7, -7, -4], [0, 17, 0, 0, 0, -2, 0, 0, -2, -2, 10, -3], [6, 0, 7, 13, -17, 0, -1, -4, 0, 0, 0, 0], [0, -13, 0, 0, 0, 14, 0, 0, -4, -2, -16, 7], [0, -1, 0, 0, 0, 1, 0, 0, 4, 3, -3, 5], [0, -12, 0, 0, 0, 2, 0, 0, 9, 11, -1, 11], [0, 4, 0, 0, 0, 10, 0, 0, -6, -10, -3, -2], [0, -15, 0, 0, 0, 6, 0, 0, 14, 9, 4, 8], [0, 2, 0, 0, 0, -4, 0, 0, 0, 4, 12, -4], [8, 0, 1, 7, 1, 0, 7, -2, 0, 0, 0, 0], [34, 0, -2, 4, -11, 0, -17, -7, 0, 0, 0, 0], [0, 8, 0, 0, 0, -4, 0, 0, -14, -5, 4, -3], [19, 0, 1, -6, 9, 0, 1, 4, 0, 0, 0, 0], [0, -22, 0, 0, 0, 4, 0, 0, -2, 6, -10, 6], [12, 0, 4, -2, -12, 0, 11, 8, 0, 0, 0, 0], [0, -4, 0, 0, 0, -6, 0, 0, 8, 12, -5, 8], [0, 2, 0, 0, 0, 5, 0, 0, 3, 2, 10, -6], [0, 3, 0, 0, 0, -7, 0, 0, 9, 6, -4, -3], [-13, 0, -3, -2, 13, 0, -9, -6, 0, 0, 0, 0], [0, 0, 0, 0, 0, -5, 0, 0, 4, 9, -1, 5], [8, 0, 6, 3, 15, 0, -13, -3, 0, 0, 0, 0], [-34, 0, 0, -4, -16, 0, 2, -2, 0, 0, 0, 0], [28, 0, 6, -2, -10, 0, -6, 6, 0, 0, 0, 0], [0, 9, 0, 0, 0, 3, 0, 0, 13, -2, 2, -1], [-22, 0, 1, 2, -2, 0, -4, 7, 0, 0, 0, 0], [30, 0, -2, 6, -33, 0, 37, -7, 0, 0, 0, 0], [0, -5, 0, 0, 0, 5, 0, 0, 7, 4, -3, 7], [18, 0, -4, -5, -16, 0, 5, -13, 0, 0, 0, 0], [0, 4, 0, 0, 0, 5, 0, 0, 0, 7, 3, -11], [-10, 0, 2, 0, -11, 0, -4, 0, 0, 0, 0, 0], [0, 15, 0, 0, 0, 8, 0, 0, -10, -10, 2, -11], [6, 0, 5, -1, 5, 0, -29, -2, 0, 0, 0, 0], [0, 0, 4, -4, 14, 0, -8, 2, 0, 0, 0, 0], [0, 14, 0, 0, 0, -10, 0, 0, 3, -5, 3, -5], [-17, 0, 2, -10, 6, 0, -15, 5, 0, 0, 0, 0], [-17, 0, -4, -10, 18, 0, -21, 7, 0, 0, 0, 0], [0, 5, 0, 0, 0, -6, 0, 0, 17, 7, 3, -6], [0, 18, 0, 0, 0, -1, 0, 0, -3, -2, 8, -6], [0, 17, 0, 0, 0, -9, 0, 0, 6, -11, 3, -8], [-2, 0, 6, -2, -20, 0, 32, 0, 0, 0, 0, 0], [0, 0, -4, -12, 12, 0, -4, 8, 0, 0, 0, 0], [0, 10, 0, 0, 0, 17, 0, 0, -10, -13, -1, -5], [-22, 0, -3, -11, 7, 0, -25, 4, 0, 0, 0, 0], [0, -5, 0, 0, 0, 22, 0, 0, -14, -12, -16, -4], [0, 7, 0, 0, 0, 3, 0, 0, 6, -5, -3, 4], [16, 0, -6, 1, 2, 0, 1, -1, 0, 0, 0, 0], [0, 3, 0, 0, 0, 5, 0, 0, -4, 3, -9, -2], [0, 3, 0, 0, 0, -2, 0, 0, 0, 0, -2, 17], [0, 2, 0, 0, 0, -11, 0, 0, 10, 21, 3, 9], [0, -6, 0, 0, 0, -2, 0, 0, -4, 0, -13, -2], [-4, 0, 6, 3, 2, 0, 5, -1, 0, 0, 0, 0], [-10, 0, 0, -8, 10, 0, 5, 6, 0, 0, 0, 0], [2, 0, 2, 8, 16, 0, -14, -2, 0, 0, 0, 0], [0, 0, 0, 0, 0, -14, 0, 0, 12, 8, 8, 0], [32, 0, 0, 0, -7, 0, 14, 2, 0, 0, 0, 0], [0, -6, 0, 0, 0, 4, 0, 0, -16, -4, -12, -6], [0, -13, 0, 0, 0, 4, 0, 0, 11, 8, -9, 15], [2, 0, -4, 5, 4, 0, 7, 5, 0, 0, 0, 0], [8, 0, -2, -7, 10, 0, 9, 9, 0, 0, 0, 0], [0, 0, 0, 0, 0, 2, 0, 0, -8, -11, 6, -13], [0, -13, 0, 0, 0, -15, 0, 0, 9, 8, 2, 12], [0, -7, 0, 0, 0, 7, 0, 0, -3, -8, 0, 1], [-28, 0, -3, 0, 14, 0, -22, -5, 0, 0, 0, 0], [27, 0, -1, -5, -25, 0, 29, -1, 0, 0, 0, 0], [0, -9, 0, 0, 0, -4, 0, 0, 4, 17, -6, -2], [0, 0, 0, 0, 0, -15, 0, 0, 14, 6, 5, 2], [0, -11, 0, 0, 0, 12, 0, 0, -7, -9, -7, 10], [0, 20, 0, 0, 0, -12, 0, 0, 8, -4, 19, -6], [-28, 0, -7, -3, 17, 0, -13, -2, 0, 0, 0, 0], [0, 17, 0, 0, 0, -3, 0, 0, -2, -13, 11, 0], [14, 0, 7, 1, -1, 0, 3, 6, 0, 0, 0, 0], [-42, 0, 2, 0, 20, 0, -34, 0, 0, 0, 0, 0], [0, 6, 0, 0, 0, -12, 0, 0, 13, 11, 0, -3], [14, 0, -7, -5, 5, 0, 5, -6, 0, 0, 0, 0], [0, 3, 0, 0, 0, 6, 0, 0, -13, -7, 9, 2], [-5, 0, -4, 0, 11, 0, -9, 4, 0, 0, 0, 0], [0, -4, 0, 0, 0, 4, 0, 0, 0, -6, 8, -8], [0, 1, 0, 0, 0, 20, 0, 0, -10, -10, -2, 1], [22, 0, 4, -4, 0, 0, 20, -6, 0, 0, 0, 0], [-4, 0, -13, -9, -7, 0, -1, 0, 0, 0, 0, 0], [4, 0, -4, -1, 26, 0, -11, -1, 0, 0, 0, 0], [0, -9, 0, 0, 0, 13, 0, 0, 5, -4, 7, 5], [0, 16, 0, 0, 0, 2, 0, 0, -15, -9, -5, -15], [16, 0, -4, 6, 7, 0, 12, 0, 0, 0, 0, 0], [0, 11, 0, 0, 0, -5, 0, 0, 10, -3, 9, 4], [0, -10, 0, 0, 0, -1, 0, 0, 5, 8, -11, 2], [0, 3, 0, 0, 0, 10, 0, 0, 1, -9, 6, -4], [-14, 0, 0, -12, 7, 0, -7, 3, 0, 0, 0, 0], [20, 0, 2, -8, -5, 0, 13, -5, 0, 0, 0, 0], [-16, 0, 1, -7, -17, 0, 1, -2, 0, 0, 0, 0], [0, -2, 0, 0, 0, -12, 0, 0, 6, -8, -10, -2], [0, 3, 0, 0, 0, -1, 0, 0, 15, 2, 8, -5], [-6, 0, 0, -8, -2, 0, 0, -4, 0, 0, 0, 0], [0, -14, 0, 0, 0, -9, 0, 0, 5, 22, 0, 8], [-13, 0, 1, -10, -8, 0, 17, 1, 0, 0, 0, 0], [0, 1, 0, 0, 0, -4, 0, 0, 2, 6, -3, -5], [-1, 0, -1, 3, 1, 0, -21, -13, 0, 0, 0, 0], [0, 12, 0, 0, 0, 9, 0, 0, -8, -7, -5, -3], [0, -5, 0, 0, 0, -7, 0, 0, -2, -5, 1, 8], [0, -1, 0, 0, 0, 13, 0, 0, -3, 6, 1, 7], [0, -7, 0, 0, 0, 10, 0, 0, -17, 1, -14, 0], [0, -1, 0, 0, 0, 7, 0, 0, -12, 3, -5, -5], [0, 13, 0, 0, 0, -3, 0, 0, 15, 6, 2, 11], [-38, 0, -4, -2, 10, 0, -18, -2, 0, 0, 0, 0], [-9, 0, 0, -6, 19, 0, -23, 0, 0, 0, 0, 0], [-18, 0, -6, -5, 14, 0, -23, 7, 0, 0, 0, 0], [28, 0, -8, -3, -2, 0, 15, -3, 0, 0, 0, 0], [-13, 0, 6, 10, -8, 0, 3, 1, 0, 0, 0, 0], [6, 0, -1, -13, -23, 0, 17, 12, 0, 0, 0, 0], [0, 7, 0, 0, 0, 0, 0, 0, -12, 1, -24, -2], [-12, 0, -4, -4, 8, 0, -11, -10, 0, 0, 0, 0], [-4, 0, 6, 13, -4, 0, -1, 7, 0, 0, 0, 0], [0, 1, 0, 0, 0, -2, 0, 0, 11, 9, 13, 4], [6, 0, -1, 5, -37, 0, 15, -10, 0, 0, 0, 0], [-11, 0, -1, -2, -20, 0, 7, 1, 0, 0, 0, 0], [-6, 0, 8, 7, 0, 0, 3, -1, 0, 0, 0, 0], [31, 0, -3, -4, 5, 0, 19, 4, 0, 0, 0, 0], [0, 7, 0, 0, 0, 4, 0, 0, 4, 2, 12, -15], [0, -13, 0, 0, 0, -2, 0, 0, 10, -3, 2, -2], [-10, 0, 2, 8, 21, 0, 1, 3, 0, 0, 0, 0], [0, -1, 0, 0, 0, 7, 0, 0, -25, -14, -6, -13], [-30, 0, 4, 10, 5, 0, -21, -7, 0, 0, 0, 0], [0, 12, 0, 0, 0, -6, 0, 0, 13, -3, 11, 2], [-18, 0, 4, 0, -5, 0, -17, -7, 0, 0, 0, 0], [0, 10, 0, 0, 0, 3, 0, 0, 11, 5, 8, 5], [-26, 0, -4, -3, -18, 0, 11, 1, 0, 0, 0, 0], [-17, 0, -1, 8, 20, 0, -4, 4, 0, 0, 0, 0], [0, 16, 0, 0, 0, -3, 0, 0, -3, -4, 6, 8], [-3, 0, 5, 1, 9, 0, -5, 11, 0, 0, 0, 0], [0, -25, 0, 0, 0, -6, 0, 0, -4, 10, 2, 5], [10, 0, -3, 1, -13, 0, -7, 0, 0, 0, 0, 0], [-26, 0, 8, 4, -6, 0, 4, 10, 0, 0, 0, 0], [39, 0, 1, 9, 3, 0, 7, -3, 0, 0, 0, 0], [-65, 0, -1, -13, 17, 0, -1, 7, 0, 0, 0, 0], [0, 3, 0, 0, 0, 9, 0, 0, -4, -15, 7, 12], [0, 11, 0, 0, 0, 9, 0, 0, -22, -21, 6, -12], [-18, 0, -2, -11, 4, 0, 25, 17, 0, 0, 0, 0], [0, 6, 0, 0, 0, -2, 0, 0, -3, 2, 5, 0], [14, 0, 6, -3, -8, 0, 17, 7, 0, 0, 0, 0], [0, -18, 0, 0, 0, 4, 0, 0, -13, 11, -13, 5], [0, 13, 0, 0, 0, 7, 0, 0, 4, -1, 1, -14], [0, -8, 0, 0, 0, -8, 0, 0, 4, -2, -2, 10], [-16, 0, 11, 5, -15, 0, -7, -2, 0, 0, 0, 0], [6, 0, 6, 8, -12, 0, 17, -14, 0, 0, 0, 0], [0, 14, 0, 0, 0, -7, 0, 0, -16, -11, 7, -4], [-17, 0, -1, 10, 30, 0, -18, -6, 0, 0, 0, 0], [-32, 0, 2, 14, 10, 0, -12, 6, 0, 0, 0, 0], [-31, 0, 7, -9, 33, 0, -19, 9, 0, 0, 0, 0], [0, 12, 0, 0, 0, 12, 0, 0, -5, -13, 4, -3], [-39, 0, 5, 7, 19, 0, -37, 3, 0, 0, 0, 0], [0, 28, 0, 0, 0, 1, 0, 0, -13, -16, 28, -20], [0, -7, 0, 0, 0, 15, 0, 0, 5, -2, -2, 6], [0, -3, 0, 0, 0, -1, 0, 0, 23, 5, 0, 8], [17, 0, -1, -2, -14, 0, -8, 2, 0, 0, 0, 0], [0, 0, 4, 9, -20, 0, 13, -3, 0, 0, 0, 0], [0, 17, 0, 0, 0, -15, 0, 0, 2, -1, 23, -2], [3, 0, 1, -9, 11, 0, 1, 3, 0, 0, 0, 0], [0, -5, 0, 0, 0, 7, 0, 0, -12, -17, -13, 4], [0, -7, 0, 0, 0, -2, 0, 0, -11, -1, -13, -2], [0, -4, 0, 0, 0, 11, 0, 0, -11, -10, -16, 3], [-11, 0, 5, -4, -9, 0, 9, 2, 0, 0, 0, 0], [9, 0, -5, -8, -6, 0, 1, -13, 0, 0, 0, 0], [4, 0, 8, -7, -10, 0, 11, -3, 0, 0, 0, 0], [0, 1, 0, 0, 0, 6, 0, 0, -3, -1, 1, -10], [-21, 0, -10, -6, -1, 0, -21, 6, 0, 0, 0, 0], [16, 0, 2, -12, -18, 0, -18, 8, 0, 0, 0, 0], [0, -5, 0, 0, 0, 4, 0, 0, 7, 9, 6, 0], [-15, 0, 14, 0, 14, 0, -25, 3, 0, 0, 0, 0], [0, -27, 0, 0, 0, -7, 0, 0, 13, 17, -18, 16], [-37, 0, -5, 0, 28, 0, 18, -2, 0, 0, 0, 0], [28, 0, 7, 1, 17, 0, -3, -2, 0, 0, 0, 0], [15, 0, -5, -3, 1, 0, 7, -7, 0, 0, 0, 0], [0, -9, 0, 0, 0, -2, 0, 0, 1, -4, 13, -9], [13, 0, -1, 2, -60, 0, 25, -3, 0, 0, 0, 0], [20, 0, 4, 5, -4, 0, 31, 7, 0, 0, 0, 0], [0, -20, 0, 0, 0, -5, 0, 0, 4, 19, -15, 9], [-11, 0, 3, 1, 25, 0, -17, 1, 0, 0, 0, 0], [0, -22, 0, 0, 0, 14, 0, 0, 0, 4, -4, 2], [-4, 0, 3, 6, -6, 0, 28, -1, 0, 0, 0, 0], [0, 17, 0, 0, 0, -7, 0, 0, -20, -13, 15, -12], [0, -7, 0, 0, 0, -6, 0, 0, 5, 11, -9, 14], [0, -12, 0, 0, 0, 11, 0, 0, 0, -15, -13, -3], [0, 29, 0, 0, 0, -3, 0, 0, 9, -15, 16, -4], [-21, 0, 2, -6, 2, 0, -7, 3, 0, 0, 0, 0], [22, 0, 4, 11, 17, 0, -9, -11, 0, 0, 0, 0], [8, 0, 0, 8, -29, 0, 16, 8, 0, 0, 0, 0], [0, -5, 0, 0, 0, -4, 0, 0, -1, 8, -15, 11], [0, 5, 0, 0, 0, -9, 0, 0, 4, 3, 13, -2], [4, 0, 6, 6, -7, 0, 15, 15, 0, 0, 0, 0], [0, 10, 0, 0, 0, 4, 0, 0, -1, 7, -3, 14], [38, 0, -6, -13, -40, 0, 33, 1, 0, 0, 0, 0], [0, -6, 0, 0, 0, 9, 0, 0, -10, -5, -1, 1], [13, 0, 8, -4, -9, 0, 9, 6, 0, 0, 0, 0], [0, -16, 0, 0, 0, 15, 0, 0, -10, -17, -20, -1], [28, 0, -15, -7, -17, 0, -1, -10, 0, 0, 0, 0], [0, 12, 0, 0, 0, -11, 0, 0, -14, -2, -15, -6], [22, 0, -3, 3, 11, 0, -29, 2, 0, 0, 0, 0], [-5, 0, 4, -6, -19, 0, 13, -2, 0, 0, 0, 0], [0, 32, 0, 0, 0, -8, 0, 0, 9, -11, 13, -19], [0, 34, 0, 0, 0, -7, 0, 0, -10, -3, 3, -11], [7, 0, 1, -7, -5, 0, 17, -7, 0, 0, 0, 0], [-4, 0, 0, -12, 16, 0, -10, 6, 0, 0, 0, 0], [0, 31, 0, 0, 0, -8, 0, 0, 2, 2, 5, -5], [-6, 0, 6, -7, -16, 0, 31, 5, 0, 0, 0, 0], [5, 0, -13, -6, 0, 0, 2, 0, 0, 0, 0, 0], [0, 10, 0, 0, 0, -8, 0, 0, 2, 10, -2, 2], [0, 29, 0, 0, 0, -1, 0, 0, -17, -11, 32, -8], [0, 6, 0, 0, 0, 3, 0, 0, -13, -16, 2, -4], [0, 0, 1, 1, 3, 0, -1, -10, 0, 0, 0, 0], [3, 0, -13, -8, 32, 0, 0, 4, 0, 0, 0, 0], [0, 5, 0, 0, 0, 18, 0, 0, 5, -1, -5, 14], [0, -9, 0, 0, 0, -22, 0, 0, 24, 10, 3, 9], [0, -9, 0, 0, 0, -2, 0, 0, 12, 10, -6, 19], [-4, 0, -12, -1, 20, 0, -31, -1, 0, 0, 0, 0], [44, 0, -2, 14, -22, 0, -6, -14, 0, 0, 0, 0], [-22, 0, -14, -7, 20, 0, -25, -9, 0, 0, 0, 0], [-35, 0, 6, 6, -4, 0, -7, -1, 0, 0, 0, 0], [0, -9, 0, 0, 0, 0, 0, 0, 6, 4, 2, 16], [26, 0, 6, 6, 1, 0, 40, -4, 0, 0, 0, 0], [0, 3, 0, 0, 0, -1, 0, 0, -15, 4, 0, 1], [0, 16, 0, 0, 0, 1, 0, 0, -14, -3, -5, 1], [0, -22, 0, 0, 0, 10, 0, 0, 5, 5, -7, 11], [-38, 0, -3, -3, 9, 0, -27, 12, 0, 0, 0, 0], [0, -20, 0, 0, 0, -2, 0, 0, 2, 15, 10, 5], [35, 0, -2, 0, 14, 0, 1, -5, 0, 0, 0, 0], [0, 9, 0, 0, 0, -3, 0, 0, -5, -8, 0, -4], [0, -22, 0, 0, 0, -5, 0, 0, 1, 28, -10, 6], [0, 9, 0, 0, 0, 8, 0, 0, -4, -15, 18, -16], [19, 0, 9, 7, 1, 0, -3, 5, 0, 0, 0, 0], [-35, 0, 3, 1, 27, 0, -51, 1, 0, 0, 0, 0], [0, -12, 0, 0, 0, 11, 0, 0, -1, -12, -4, -9], [0, -1, 0, 0, 0, 18, 0, 0, -12, -8, -2, -15]]
